tag_error

Macro tag_error 

macro_rules! tag_error {
    ( $type:ident $(,)? ) => { ... };
    ( $type:ident, $display:expr $(,)? ) => { ... };
}
Define an error type implemented as an empty struct.

The first argument is the type name. The second optional argument is the Display representation, which defaults to the type name.