CauseRef

Struct CauseRef 

pub struct CauseRef<'problem, ErrorT> {
    pub problem: &'problem Problem,
    pub depth: usize,
    pub error: &'problem ErrorT,
    pub attachments: &'problem ThinVec<CapturedAttachment>,
}
Reference to a Cause.

Fields

problem: &'problem Problem

Containing problem.

depth: usize

Depth in causation chain.

error: &'problem ErrorT

Error.

This error could be either on the causation chain or nested in source.

attachments: &'problem ThinVec<CapturedAttachment>

Attachments.

Implementations

Source

impl<'problem, ErrorT> CauseRef<'problem, ErrorT>

pub fn new( problem: &'problem Problem, depth: usize, error: &'problem ErrorT, attachments: &'problem ThinVec<CapturedAttachment>, ) -> Self

Constructor.

pub fn cause(&self) -> &'problem Cause

The cause.

pub fn iter_under(&self) -> CauseRefIterator<'problem>

Iterate the causation chain starting from under this cause ending at the root.

Note that this will skip over source.

pub fn under(&self) -> Option<CauseRef<'problem, CapturedError>>

The cause under this one in the causation chain.

It will be None if we are the root cause.

Note that this will skip over source.

pub fn is_top(&self) -> bool

Whether we are the top cause of the chain.

pub fn is_root(&self) -> bool

Whether we are the root cause of the chain.