Problem

Struct Problem 

pub struct Problem {
    pub causes: ThinVec<Cause>,
}
A problem is a simple wrapper for an error causation chain.

Each link in the chain is a Cause, which is itself a simple wrapper for a CapturedError. Each cause can have any number of attachments.

Though you can iterate a problem directly to access its causes, often it is easier to use one of the many convenience functions in the ProblemImplementation and Causes traits.

Note that this type does not itself implement Error directly, but you can use into_error if compatibility is needed.

For more information and usage examples see the Problemo home page.

Fields

causes: ThinVec<Cause>

Causes in order of causation from top to root.

Implementations

Source

impl Problem

pub fn new(error: CapturedError) -> Self

Constructor.

pub fn into_error(self) -> ProblemAsError

Add support for Error.

Take care to avoid adding it into a Problem’s causation chain.

pub fn via<ErrorT>(self, error: ErrorT) -> Self
where ErrorT: 'static + Error + Send + Sync,

Adds the error to the top of the causation chain.

pub fn with<AttachmentT>(self, attachment: AttachmentT) -> Self
where AttachmentT: Any + Send + Sync,

Attach to the top cause.

pub fn with_once<AttachmentT>(self, attachment: AttachmentT) -> Self
where AttachmentT: Any + Send + Sync,

Attach only if we don’t already have one of the same type.

pub fn maybe_with<AttachmentT>(self, attachment: Option<AttachmentT>) -> Self
where AttachmentT: Any + Send + Sync,

Attach to the top cause if Some.

pub fn maybe_with_once<AttachmentT>( self, attachment: Option<AttachmentT>, ) -> Self
where AttachmentT: Any + Send + Sync,

Attach to the top cause if Some and we don’t already have one of the same type.

pub fn with_location(self) -> Self

Attach a Location (via Location::caller) if we don’t already have one.

pub fn with_backtrace(self) -> Self

Attach a backtrace if we don’t already have one.

pub fn into_problems(self) -> Problems

Convert into Problems.

Will return the first cause that is a Problems, otherwise will return a new Problems with just self.

Note that this is identical to calling Problems::from(problem).