Problems

Struct Problems 

pub struct Problems {
    pub problems: ThinVec<Problem>,
    pub critical_error_types: HashSet<TypeId>,
}
A simple wrapper for a vector of Problem.

Useful for accumulating problems, as it implements ProblemReceiver. By default it will swallow all problems into its vector. However, it can also be configured to fail fast on specific error types by calling handle_type_as_critical before use.

After use, you may want to call check to fail if there were problems.

Note that this type implements Error and as such can be used in the causation chain of a Problem. This can be thought of as “packing” many problems into one. It can then be “unpacked” via Problem::into_problems.

Fields

problems: ThinVec<Problem>

Problems.

critical_error_types: HashSet<TypeId>

Critical error type IDs.

Implementations

Source

impl Problems

pub fn with_capacity(capacity: usize) -> Self

Constructor.

pub fn is_empty(&self) -> bool

True if there are no problems.

pub fn count(&self) -> usize

The number of problems.

pub fn iter(&self) -> Iter<'_, Problem>

Iterate problems.

pub fn handle_type_as_critical<ErrorT>(&mut self)
where ErrorT: Any + Error,

Marks a top error type as critical.

pub fn is_critical(&self, problem: &Problem) -> bool

True if the problem’s top error is critical.

pub fn is_error_critical(&self, error: &CapturedError) -> bool

True if the error is critical.

pub fn add<ProblemT>(&mut self, problem: ProblemT)
where ProblemT: Into<Problem>,

Add a problem.

pub fn check(self) -> Result<Self, Self>

Fails with self if there is at least one problem.

Other returns self.

pub fn into_unique(self) -> Self

Into unique problems.

Equality is tested for using the first CauseEquality or CauseComparison found in each problem.

pub fn iter_unique(self) -> impl Iterator<Item = Problem>

Iterate unique problems.

Equality is tested for using the first CauseEquality or CauseComparison found in each problem.

pub fn iter_unique_refs<'this>( &'this self, ) -> impl Iterator<Item = &'this Problem>

Iterate unique problems.

Equality is tested for using the first CauseEquality or CauseComparison found in each problem.