pub struct CauseRef<'problem, ErrorT> {
pub problem: &'problem Problem,
pub depth: usize,
pub error: &'problem ErrorT,
pub attachments: &'problem ThinVec<CapturedAttachment>,
}Expand description
Reference to a Cause.
Fields
problem: &'problem ProblemContaining problem.
depth: usizeDepth in causation chain.
error: &'problem ErrorTError.
This error could be either on the causation chain or nested in source.
attachments: &'problem ThinVec<CapturedAttachment>Attachments.
Implementations
Sourceimpl<'problem, ErrorT> CauseRef<'problem, ErrorT>
impl<'problem, ErrorT> CauseRef<'problem, ErrorT>
Sourcepub fn new(
problem: &'problem Problem,
depth: usize,
error: &'problem ErrorT,
attachments: &'problem ThinVec<CapturedAttachment>,
) -> Self
pub fn new( problem: &'problem Problem, depth: usize, error: &'problem ErrorT, attachments: &'problem ThinVec<CapturedAttachment>, ) -> Self
Constructor.
Sourcepub fn iter_under(&self) -> CauseRefIterator<'problem> ⓘ
pub fn iter_under(&self) -> CauseRefIterator<'problem> ⓘ
Iterate the causation chain starting from under this cause ending at the root.
Note that this will skip over source.
Sourcepub fn under(&self) -> Option<CauseRef<'problem, CapturedError>>
pub fn under(&self) -> Option<CauseRef<'problem, CapturedError>>