pub struct Problem {
pub causes: ThinVec<Cause>,
}Expand description
A problem is a simple wrapper for an error causation chain.
Each link in the chain is a Cause, which is itself a simple wrapper for a CapturedError. Each cause can have any number of attachments.
Though you can iterate a problem directly to access its causes, often it is easier to use one of the many convenience functions in the ProblemImplementation and Causes traits.
Note that this type does not itself implement Error directly, but you can use into_error if compatibility is needed.
For more information and usage examples see the Problemo home page.
Fields
causes: ThinVec<Cause>Causes in order of causation from top to root.
Implementations
Sourceimpl Problem
impl Problem
Sourcepub fn new(error: CapturedError) -> Self
pub fn new(error: CapturedError) -> Self
Constructor.
Sourcepub fn into_error(self) -> ProblemAsError
pub fn into_error(self) -> ProblemAsError
Sourcepub fn via<ErrorT>(self, error: ErrorT) -> Self
pub fn via<ErrorT>(self, error: ErrorT) -> Self
Adds the error to the top of the causation chain.
Sourcepub fn with_once<AttachmentT>(self, attachment: AttachmentT) -> Self
pub fn with_once<AttachmentT>(self, attachment: AttachmentT) -> Self
Attach only if we don’t already have one of the same type.
Sourcepub fn maybe_with<AttachmentT>(self, attachment: Option<AttachmentT>) -> Self
pub fn maybe_with<AttachmentT>(self, attachment: Option<AttachmentT>) -> Self
Attach to the top cause if Some.
Sourcepub fn maybe_with_once<AttachmentT>(
self,
attachment: Option<AttachmentT>,
) -> Self
pub fn maybe_with_once<AttachmentT>( self, attachment: Option<AttachmentT>, ) -> Self
Attach to the top cause if Some and we don’t already have one of the same type.
Sourcepub fn with_location(self) -> Self
pub fn with_location(self) -> Self
Attach a Location (via Location::caller) if we don’t already have one.
Sourcepub fn with_backtrace(self) -> Self
pub fn with_backtrace(self) -> Self
Attach a backtrace if we don’t already have one.